@@ -28,7 +28,7 @@ class CentreDelegate : public QStyledItemDelegate
 {
     Q_OBJECT
 public:
-    CentreDelegate(QWidget* parent = nullptr) : QStyledItemDelegate(parent) {}
+    explicit CentreDelegate(QWidget* parent = nullptr) : QStyledItemDelegate(parent) {}
     void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const override;
 };
 
