@@ -31,6 +31,7 @@
 #include "templatepickdlg.h"
 #include "lib/timeedit.h"
 #include "lib/timespinbox.h"
+#include "lib/tooltip.h"
 #include "config-kalarm.h"
 #include "kalarm_debug.h"
 
@@ -55,6 +56,7 @@
 #include <QDialogButtonBox>
 #include <QLocale>
 #include <QStyle>
+using namespace Qt::Literals::StringLiterals;
 
 using namespace KCal;
 using namespace KAlarmCal;
@@ -64,7 +66,7 @@ namespace
 const char EDIT_DIALOG_NAME[] = "EditDialog";
 const char TEMPLATE_DIALOG_NAME[] = "EditTemplateDialog";
 const char EDIT_MORE_KEY[]   = "EditMore";
-const QLatin1String EDIT_MORE_GROUP("ShowOpts");
+const QLatin1StringView EDIT_MORE_GROUP("ShowOpts");
 const int  maxDelayTime = 99*60 + 59;    // < 100 hours
 }
 
@@ -196,7 +198,7 @@ void EditAlarmDlg::init(const KAEvent& event)
         {
             mLoadTemplateButton = mButtonBox->addButton(i18nc("@action:button", "Load Template..."),
                                                         QDialogButtonBox::HelpRole);
-            mLoadTemplateButton->setToolTip(i18nc("@info:tooltip", "Select an alarm template to preset the alarm"));
+            KAlarm::setToolTip(mLoadTemplateButton, i18nc("@info:tooltip", "Select an alarm template to preset the alarm"));
         }
     }
     mButtonBox->addButton(QDialogButtonBox::Cancel);
@@ -287,14 +289,14 @@ void EditAlarmDlg::init(const KAEvent& event)
         topLayout->addWidget(templateTimeBox);
         auto grid = new QGridLayout(templateTimeBox);
         mTemplateTimeGroup = new ButtonGroup(templateTimeBox);
-        connect(mTemplateTimeGroup, &ButtonGroup::buttonSet, this, &EditAlarmDlg::slotTemplateTimeType);
-        connect(mTemplateTimeGroup, &ButtonGroup::buttonSet, this, &EditAlarmDlg::contentsChanged);
+        connect(mTemplateTimeGroup, &ButtonGroup::selectionChanged, this, &EditAlarmDlg::slotTemplateTimeType);
+        connect(mTemplateTimeGroup, &ButtonGroup::selectionChanged, this, &EditAlarmDlg::contentsChanged);
 
         mTemplateDefaultTime = new RadioButton(i18nc("@option:radio", "Default time"), templateTimeBox);
         mTemplateDefaultTime->setReadOnly(mReadOnly);
         mTemplateDefaultTime->setWhatsThis(i18nc("@info:whatsthis", "Do not specify a start time for alarms based on this template. "
                                                 "The normal default start time will be used."));
-        mTemplateTimeGroup->addButton(mTemplateDefaultTime);
+        mTemplateTimeGroup->insertButton(mTemplateDefaultTime);
         grid->addWidget(mTemplateDefaultTime, 0, 0, Qt::AlignLeft);
 
         QWidget* box = new QWidget(templateTimeBox);
@@ -304,7 +306,7 @@ void EditAlarmDlg::init(const KAEvent& event)
         mTemplateUseTime->setReadOnly(mReadOnly);
         mTemplateUseTime->setWhatsThis(i18nc("@info:whatsthis", "Specify a start time for alarms based on this template."));
         layout->addWidget(mTemplateUseTime);
-        mTemplateTimeGroup->addButton(mTemplateUseTime);
+        mTemplateTimeGroup->insertButton(mTemplateUseTime);
         mTemplateTime = new TimeEdit();
         mTemplateTime->setReadOnly(mReadOnly);
         mTemplateTime->setWhatsThis(xi18nc("@info:whatsthis",
@@ -318,7 +320,7 @@ void EditAlarmDlg::init(const KAEvent& event)
         mTemplateAnyTime = new RadioButton(i18nc("@option:radio", "Date only"), templateTimeBox);
         mTemplateAnyTime->setReadOnly(mReadOnly);
         mTemplateAnyTime->setWhatsThis(xi18nc("@info:whatsthis", "Set the <interface>Any time</interface> option for alarms based on this template."));
-        mTemplateTimeGroup->addButton(mTemplateAnyTime);
+        mTemplateTimeGroup->insertButton(mTemplateAnyTime);
         grid->addWidget(mTemplateAnyTime, 1, 0, Qt::AlignLeft);
 
         box = new QWidget(templateTimeBox);
@@ -330,7 +332,7 @@ void EditAlarmDlg::init(const KAEvent& event)
                                                   "Set alarms based on this template to start after the specified time "
                                                  "interval from when the alarm is created."));
         layout->addWidget(mTemplateUseTimeAfter);
-        mTemplateTimeGroup->addButton(mTemplateUseTimeAfter);
+        mTemplateTimeGroup->insertButton(mTemplateUseTimeAfter);
         mTemplateTimeAfter = new TimeSpinBox(1, maxDelayTime);
         mTemplateTimeAfter->setValue(1439);
         mTemplateTimeAfter->setReadOnly(mReadOnly);
@@ -783,8 +785,8 @@ void EditAlarmDlg::setEvent(KAEvent& event, const QString& text, bool trial)
             dt = KADateTime(QDate(2000,1,1), mTemplateTime->time());
     }
 
-    const int lateCancel = (trial || !mLateCancel->isEnabled()) ? 0 : mLateCancel->minutes();
-    type_setEvent(event, dt, (mName ? mName->text() : QString()), text, lateCancel, trial);
+    const int lateCancelTime = (trial || !mLateCancel->isEnabled()) ? 0 : mLateCancel->minutes();
+    type_setEvent(event, dt, (mName ? mName->text() : QString()), text, lateCancelTime, trial);
 
     if (!trial)
     {
@@ -805,10 +807,10 @@ void EditAlarmDlg::setEvent(KAEvent& event, const QString& text, bool trial)
             {
                 bool deferral = true;
                 bool deferReminder = false;
-                const int reminder = mReminder ? mReminder->minutes() : 0;
-                if (reminder)
+                const int reminderTime = mReminder ? mReminder->minutes() : 0;
+                if (reminderTime)
                 {
-                    DateTime remindTime = mAlarmDateTime.addMins(-reminder);
+                    DateTime remindTime = mAlarmDateTime.addMins(-reminderTime);
                     if (mDeferDateTime >= remindTime)
                     {
                         if (remindTime > KADateTime::currentUtcDateTime())
@@ -877,7 +879,7 @@ void EditAlarmDlg::showEvent(QShowEvent* se)
 
     if (theApp()->needWindowFocusFix())
     {
-        QApplication::setActiveWindow(this);
+        activateWindow();
         QTimer::singleShot(0, this, &EditAlarmDlg::focusFixTimer);   //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
     }
 }
@@ -894,7 +896,7 @@ void EditAlarmDlg::focusFixTimer()
     if (theApp()->needWindowFocusFix()
     &&  QApplication::focusWidget()->window() != this)
     {
-        QApplication::setActiveWindow(this);
+        activateWindow();
         QTimer::singleShot(0, this, &EditAlarmDlg::focusFixTimer);   //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
     }
 }
@@ -911,7 +913,7 @@ bool EditAlarmDlg::eventFilter(QObject*, QEvent* e)
     if (theApp()->needWindowFocusFix())
     {
         if (e->type() == QEvent::MouseButtonPress)
-            QApplication::setActiveWindow(this);
+            activateWindow();
     }
     return false;
 }
@@ -1114,12 +1116,12 @@ bool EditAlarmDlg::validate()
     {
         KAEvent recurEvent;
         int longestRecurMinutes = -1;
-        int reminder = mReminder ? mReminder->minutes() : 0;
-        if (reminder  &&  !mReminder->isOnceOnly())
+        int reminderTime = mReminder ? mReminder->minutes() : 0;
+        if (reminderTime  &&  !mReminder->isOnceOnly())
         {
             mRecurrenceEdit->updateEvent(recurEvent, false);
             longestRecurMinutes = recurEvent.longestRecurrenceInterval().asSeconds() / 60;
-            if (longestRecurMinutes  &&  reminder >= longestRecurMinutes)
+            if (longestRecurMinutes  &&  reminderTime >= longestRecurMinutes)
             {
                 mTabs->setCurrentIndex(mMainPageIndex);
                 mReminder->setFocusOnCount();
@@ -1136,7 +1138,7 @@ bool EditAlarmDlg::validate()
                 longestRecurMinutes = recurEvent.longestRecurrenceInterval().asSeconds() / 60;
             }
             if (longestRecurMinutes > 0
-            &&  recurEvent.repetition().intervalMinutes() * recurEvent.repetition().count() >= longestRecurMinutes - reminder)
+            &&  recurEvent.repetition().intervalMinutes() * recurEvent.repetition().count() >= longestRecurMinutes - reminderTime)
             {
                 KAMessageBox::error(this, i18nc("@info", "The duration of a repetition within the recurrence must be less than the recurrence interval minus any reminder period"));
                 mRecurrenceEdit->activateSubRepetition();   // display the alarm repetition dialog again
@@ -1315,14 +1317,14 @@ void EditAlarmDlg::slotEditDeferral()
     // deletion of EditAlarmDlg, and on return from this function).
     AutoQPointer<DeferAlarmDlg> deferDlg = new DeferAlarmDlg((deferred ? mDeferDateTime : DateTime(now.addSecs(60).toTimeSpec(start.timeSpec()))),
                                                              start.isDateOnly(), deferred, this);
-    deferDlg->setObjectName(QLatin1StringView("EditDeferDlg"));    // used by LikeBack
+    deferDlg->setObjectName("EditDeferDlg"_L1);    // used by LikeBack
     if (limit)
     {
         // Don't allow deferral past the next recurrence
-        int reminder = mReminder ? mReminder->minutes() : 0;
-        if (reminder)
+        int reminderTime = mReminder ? mReminder->minutes() : 0;
+        if (reminderTime)
         {
-            DateTime remindTime = start.addMins(-reminder);
+            DateTime remindTime = start.addMins(-reminderTime);
             if (KADateTime::currentUtcDateTime() < remindTime)
                 start = remindTime;
         }
@@ -1453,7 +1455,7 @@ void EditAlarmDlg::slotSetSubRepetition()
 * Called when one of the template time radio buttons is clicked,
 * to enable or disable the template time entry spin boxes.
 */
-void EditAlarmDlg::slotTemplateTimeType(QAbstractButton*)
+void EditAlarmDlg::slotTemplateTimeType(QAbstractButton*, QAbstractButton*)
 {
     mTemplateTime->setEnabled(mTemplateUseTime->isChecked());
     mTemplateTimeAfter->setEnabled(mTemplateUseTimeAfter->isChecked());
@@ -1486,7 +1488,7 @@ void EditAlarmDlg::setWakeFromSuspendEnabledStatus()
     }
 }
 
-bool EditAlarmDlg::dateOnly() const
+bool EditAlarmDlg::isDateOnly() const
 {
     return mTimeWidget ? mTimeWidget->anyTime() : mTemplateAnyTime->isChecked();
 }
