@@ -12,11 +12,10 @@
 
 #include "kalarmcal_export.h"
 
-#include <QtGlobal>
-
+#include <QtTypes>
 class QString;
 
-namespace KIdentityManagement
+namespace KIdentityManagementCore
 {
 class IdentityManager;
 }
@@ -32,7 +31,7 @@ namespace KAlarmCal
 namespace Identities
 {
 /** Return the unique identity manager instance. It is created if it does not already exist. */
-KALARMCAL_EXPORT KIdentityManagement::IdentityManager* identityManager();
+KALARMCAL_EXPORT KIdentityManagementCore::IdentityManager* identityManager();
 
 /** Return whether any identities exist. */
 KALARMCAL_EXPORT bool identitiesExist();
