@@ -378,14 +378,14 @@ bool SpinBox2p::eventFilter(QObject* obj, QEvent* e)
             case QEvent::HoverEnter:
             {
                 auto* he = (QHoverEvent*)e;
-                QApplication::postEvent(mSpinbox2, new QHoverEvent(e->type(), QPoint(1, he->position().toPoint().y()), he->oldPos()));
+                QApplication::postEvent(mSpinbox2, new QHoverEvent(e->type(), QPointF(1.0, he->position().y()), he->globalPosition(), he->oldPosF()));
                 updateButtons = true;
                 break;
             }
             case QEvent::HoverLeave:
             {
                 auto* he = (QHoverEvent*)e;
-                QApplication::postEvent(mSpinbox2, new QHoverEvent(e->type(), he->position().toPoint(), QPoint(1, he->oldPos().y())));
+                QApplication::postEvent(mSpinbox2, new QHoverEvent(e->type(), he->position(), he->globalPosition(), QPointF(1.0, he->oldPosF().y())));
                 updateButtons = true;
                 break;
             }
@@ -496,10 +496,10 @@ void SpinBox2p::getMetrics() const
     {
         // Check whether both mSpinbox spin buttons are on the same side of the control,
         // and if not, show only the normal spinbox without extra spin buttons.
-        const QRect upRect   = mSpinbox->style()->subControlRect(QStyle::CC_SpinBox, &option, QStyle::SC_SpinBoxUp);
-        const QRect downRect = mSpinbox->style()->subControlRect(QStyle::CC_SpinBox, &option, QStyle::SC_SpinBoxDown);
-        bool showUpdown2 = ((upRect.left() > editRect.left())  &&  (downRect.left() > editRect.left()))
-                       ||  ((upRect.right() < editRect.right())  &&  (downRect.right() < editRect.right()));
+        const QRect upRect_   = mSpinbox->style()->subControlRect(QStyle::CC_SpinBox, &option, QStyle::SC_SpinBoxUp);
+        const QRect downRect_ = mSpinbox->style()->subControlRect(QStyle::CC_SpinBox, &option, QStyle::SC_SpinBoxDown);
+        bool showUpdown2 = ((upRect_.left() > editRect.left())  &&  (downRect_.left() > editRect.left()))
+                       ||  ((upRect_.right() < editRect.right())  &&  (downRect_.right() < editRect.right()));
         setShowUpdown2(showUpdown2);
         if (!mShowUpdown2)
             return;
@@ -779,12 +779,12 @@ void SpinMirror::mouseEvent(QMouseEvent* e)
     if (mReadOnly)
         return;
     QPointF pt = e->pos();
-    QGraphicsItem* item = scene()->itemAt(pt, QTransform());
+    const QGraphicsItem* item = scene()->itemAt(pt, QTransform());
     if (item == mButtons)
         pt = spinboxPoint(pt);
     else
         pt = QPointF(0, 0);  // allow auto-repeat to stop
-    QApplication::postEvent(mSpinbox, new QMouseEvent(e->type(), pt, e->button(), e->buttons(), e->modifiers()));
+    QApplication::postEvent(mSpinbox, new QMouseEvent(e->type(), pt, e->globalPosition(), e->button(), e->buttons(), e->modifiers()));
 }
 
 /******************************************************************************
@@ -796,7 +796,7 @@ void SpinMirror::wheelEvent(QWheelEvent* e)
     if (mReadOnly)
         return;
     QPointF pt = e->position();
-    QGraphicsItem* item = scene()->itemAt(pt, QTransform());
+    const QGraphicsItem* item = scene()->itemAt(pt, QTransform());
     if (item == mButtons)
     {
         pt = spinboxPoint(pt);
@@ -830,8 +830,7 @@ bool SpinMirror::event(QEvent* e)
         case QEvent::Leave:
             if (mMainSpinbox->rect().contains(mMainSpinbox->mapFromGlobal(QCursor::pos())))
                 break;
-            // fall through to QEvent::Enter
-            [[fallthrough]];
+            [[fallthrough]];   // fall through to QEvent::Enter
         case QEvent::Enter:
             QApplication::postEvent(mMainSpinbox, new QEvent(e->type()));
             break;
@@ -839,11 +838,10 @@ bool SpinMirror::event(QEvent* e)
             he = (QHoverEvent*)e;
             if (mMainSpinbox->rect().contains(mMainSpinbox->mapFromGlobal(QCursor::pos())))
                 break;
-            // fall through to QEvent::HoverEnter
-            [[fallthrough]];
+            [[fallthrough]];   // fall through to QEvent::HoverEnter
         case QEvent::HoverEnter:
             he = (QHoverEvent*)e;
-            QApplication::postEvent(mMainSpinbox, new QHoverEvent(e->type(), he->position().toPoint(), he->oldPos()));
+            QApplication::postEvent(mMainSpinbox, new QHoverEvent(e->type(), he->position(), he->globalPosition(), he->oldPosF()));
             break;
         case QEvent::HoverMove:
             he = (QHoverEvent*)e;
@@ -857,7 +855,7 @@ bool SpinMirror::event(QEvent* e)
 
     if (he)
     {
-        QApplication::postEvent(mSpinbox, new QHoverEvent(e->type(), spinboxPoint(he->position()), spinboxPoint(he->oldPosF())));
+        QApplication::postEvent(mSpinbox, new QHoverEvent(e->type(), spinboxPoint(he->position()), he->globalPosition(), spinboxPoint(he->oldPosF())));
         setButtonsImage();
     }
 
