@@ -46,6 +46,7 @@
 #include <QTimeZone>
 #include <QTimer>
 #include <QUrl>
+using namespace Qt::Literals::StringLiterals;
 
 using namespace KAlarmCal;
 
@@ -218,7 +219,7 @@ void MessageDisplayHelper::initTexts()
             static const QRegularExpression re(QStringLiteral("^(<[^>]+>)*"));  // search for HTML tag "<...>"
             const QRegularExpressionMatch match = re.match(s);
             // Prefix the time, plus a newline, to "Reminder", inside any HTML tags.
-            s.insert(match.capturedEnd(0), mTexts.time + QLatin1String("<br/>"));
+            s.insert(match.capturedEnd(0), mTexts.time + "<br/>"_L1);
             mTexts.timeFull = s;
         }
     }
@@ -252,7 +253,7 @@ void MessageDisplayHelper::initTexts()
 
                         QMimeDatabase db;
                         QMimeType mime = db.mimeTypeForUrl(url);
-                        if (mime.name() == QLatin1String("application/octet-stream"))
+                        if (mime.name() == "application/octet-stream"_L1)
                             mime = db.mimeTypeForData(mTempFile);
                         mTexts.fileType = File::fileType(mime);
                         switch (mTexts.fileType)
@@ -271,7 +272,7 @@ void MessageDisplayHelper::initTexts()
                         switch (mTexts.fileType)
                         {
                             case File::Type::Image:
-                                mTexts.message = QLatin1String(R"(<div align="center"><img src=")") + mTempFile->fileName() + QLatin1String(R"("></div>)");
+                                mTexts.message = QLatin1StringView(R"(<div align="center"><img src=")") + mTempFile->fileName() + QLatin1StringView(R"("></div>)");
                                 mTempFile->close();   // keep the file available to be displayed
                                 break;
                             case File::Type::TextFormatted:
@@ -455,7 +456,7 @@ QString MessageDisplayHelper::dateTimeToDisplay() const
             const QDateTime dt = mDateTime.qDateTime();
             tm = locale.toString(dt, QLocale::ShortFormat);
             if (showZone)
-                tm += QLatin1Char(' ') + mDateTime.timeZone().displayName(dt, QTimeZone::ShortName, locale);
+                tm += ' '_L1 + mDateTime.namedTimeZone().displayName(dt, QTimeZone::ShortName, locale);
         }
     }
     return tm;
@@ -592,7 +593,7 @@ bool MessageDisplayHelper::saveProperties(KConfigGroup& config)
             }
             else if (mDateTime.timeType() == KADateTime::TimeZone)
             {
-                const QTimeZone tz = mDateTime.timeZone();
+                const QTimeZone tz = mDateTime.namedTimeZone();
                 if (tz.isValid())
                     zone = tz.id();
             }
