@@ -31,6 +31,7 @@
 #include <QSaveFile>
 #include <QDir>
 #include <QStandardPaths>
+using namespace Qt::Literals::StringLiterals;
 
 #include <time.h>
 
@@ -42,7 +43,7 @@ namespace
 {
 
 // Config file entry names
-const QLatin1String GENERAL_GROUP("General");
+const QLatin1StringView GENERAL_GROUP("General");
 
 // Config file entry name for temporary use
 const char* TEMP = "Temp";
@@ -76,10 +77,9 @@ void splitXTermCommands();
 } // namespace
 
 // Config file entry names for notification messages
-const QLatin1String Preferences::QUIT_WARN("QuitWarn");
-const QLatin1String Preferences::ASK_AUTO_START("AskAutoStart");
-const QLatin1String Preferences::CONFIRM_ALARM_DELETION("ConfirmAlarmDeletion");
-const QLatin1String Preferences::EMAIL_QUEUED_NOTIFY("EmailQueuedNotify");
+const QLatin1StringView Preferences::QUIT_WARN("QuitWarn");
+const QLatin1StringView Preferences::CONFIRM_ALARM_DELETION("ConfirmAlarmDeletion");
+const QLatin1StringView Preferences::EMAIL_QUEUED_NOTIFY("EmailQueuedNotify");
 const bool  default_quitWarn             = true;
 const bool  default_emailQueuedNotify    = false;
 const bool  default_confirmAlarmDeletion = true;
@@ -92,8 +92,6 @@ bool                 Preferences::mUsingDefaults = false;
 Holidays*            Preferences::mHolidays = nullptr;   // always non-null after Preferences initialisation
 QString              Preferences::mPreviousVersion;
 Preferences::Backend Preferences::mPreviousBackend;
-// Change tracking
-bool           Preferences::mAutoStartChangedByUser = false;
 
 
 Preferences* Preferences::self()
@@ -107,6 +105,11 @@ Preferences* Preferences::self()
         KAMessageBox::setDefaultShouldBeShownContinue(CONFIRM_ALARM_DELETION, default_confirmAlarmDeletion);
 
         mInstance = new Preferences;
+
+        // Ensure that AutoStart corresponds to RunMode
+        const bool autostart = (runMode() == RunMode_Auto);
+        if (mInstance->self()->base_AutoStart() != autostart)
+            mInstance->self()->setBase_AutoStart(autostart);
     }
     return mInstance;
 }
@@ -175,22 +178,28 @@ void Preferences::setAutoHideSystemTray(int timeout)
     self()->setBase_AutoHideSystemTray(timeout);
 }
 
-void Preferences::setAskAutoStart(bool yes)
-{
-    KAMessageBox::saveDontShowAgainYesNo(ASK_AUTO_START, !yes);
-}
-
 /******************************************************************************
-* Set the NoAutoStart condition.
+* Set the RunMode.
+* The AutoStart entry also needs to be set, because it controls autostart via
+* the kalarm.autostart.desktop file.
 * On KDE desktops, the "X-KDE-autostart-condition" entry in
-* kalarm.autostart.desktop references this to determine whether to autostart KAlarm.
+* kalarm.autostart.desktop references the AutoStart config entry to determine
+* whether to autostart KAlarm.
+* The kalarm.autostart.desktop entry is
+*   X-KDE-autostart-condition=kalarmrc:General:AutoStart:false
+* where the parameters are:
+*   kalarmrc  : the config file to use
+*   General   : the section within the config file
+*   AutoStart : the entry which specifies whether to autostart
+*   false     : the default value to use, i.e. don't autostart KAlarm unless
+*               there is an entry 'AutoStart=true' in kalarmrc [General]
 * On non-KDE desktops, the "X-KDE-autostart-condition" entry in
 * kalarm.autostart.desktop doesn't have any effect, so that KAlarm will be
 * autostarted even if it is set not to autostart. Adding a "Hidden" entry to,
 * and removing the "OnlyShowIn=KDE" entry from, a user-modifiable copy of the
 * file fixes this.
 */
-void Preferences::setNoAutoStart(bool yes)
+void Preferences::setRunMode(RunMode mode)
 {
     // Find the existing kalarm.autostart.desktop file, and whether it's writable.
     bool existingRO = true;   // whether the existing file is read-only
@@ -199,7 +208,7 @@ void Preferences::setNoAutoStart(bool yes)
     const QStringList autostartDirs = QStandardPaths::standardLocations(QStandardPaths::GenericConfigLocation);
     for (const QString& dir : autostartDirs)
     {
-        const QString file = dir + QLatin1String("/autostart/") + AUTOSTART_FILE;
+        const QString file = dir + "/autostart/"_L1 + AUTOSTART_FILE;
         if (QFile::exists(file))
         {
             QFileInfo info(file);
@@ -219,10 +228,10 @@ void Preferences::setNoAutoStart(bool yes)
     if (existingRO)
     {
         configDirRW = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation);
-        autostartFileRW = configDirRW + QLatin1String("/autostart/") + AUTOSTART_FILE;
+        autostartFileRW = configDirRW + "/autostart/"_L1 + AUTOSTART_FILE;
         if (configDirRW.isEmpty())
         {
-            qCWarning(KALARM_LOG) << "Preferences::setNoAutoStart: No writable autostart file path";
+            qCWarning(KALARM_LOG) << "Preferences::setRunMode: No writable autostart file path";
             return;
         }
         if (QFile::exists(autostartFileRW))
@@ -230,7 +239,7 @@ void Preferences::setNoAutoStart(bool yes)
             QFileInfo info(autostartFileRW);
             if (!info.isReadable() || !info.isWritable())
             {
-                qCWarning(KALARM_LOG) << "Preferences::setNoAutoStart: Autostart file is not read/write:" << autostartFileRW;
+                qCWarning(KALARM_LOG) << "Preferences::setRunMode: Autostart file is not read/write:" << autostartFileRW;
                 return;
             }
         }
@@ -243,12 +252,12 @@ void Preferences::setNoAutoStart(bool yes)
         QFile file(autostartFile);
         if (!file.open(QIODevice::ReadOnly))
         {
-            qCWarning(KALARM_LOG) << "Preferences::setNoAutoStart: Error reading autostart file:" << autostartFile;
+            qCWarning(KALARM_LOG) << "Preferences::setRunMode: Error reading autostart file:" << autostartFile;
             return;
         }
         QTextStream stream(&file);
         stream.setAutoDetectUnicode(true);
-        lines = stream.readAll().split(QLatin1Char('\n'));
+        lines = stream.readAll().split('\n'_L1);
         for (int i = 0; i < lines.size(); ++i)
         {
             const QString line = lines.at(i).trimmed();
@@ -257,8 +266,8 @@ void Preferences::setNoAutoStart(bool yes)
                 lines.removeAt(i);
                 --i;
             }
-            else if (line.startsWith(QLatin1String("Hidden="))
-                 ||  line.startsWith(QLatin1String("OnlyShowIn=")))
+            else if (line.startsWith("Hidden="_L1)
+                 ||  line.startsWith("OnlyShowIn="_L1))
             {
                 lines.removeAt(i);
                 update = true;
@@ -267,7 +276,7 @@ void Preferences::setNoAutoStart(bool yes)
         }
     }
 
-    if (yes)
+    if (mode == RunMode_Manual)
     {
         // Add a "Hidden" entry to the local kalarm.autostart.desktop file, to
         // prevent autostart from happening.
@@ -277,35 +286,36 @@ void Preferences::setNoAutoStart(bool yes)
     if (update)
     {
         // Write the updated file
-        QFileInfo info(configDirRW + QLatin1String("/autostart"));
+        QFileInfo info(configDirRW + "/autostart"_L1);
         if (!info.exists())
         {
             // First, create the directory for it.
             if (!QDir(configDirRW).mkdir(QStringLiteral("autostart")))
             {
-                qCWarning(KALARM_LOG) << "Preferences::setNoAutoStart: Error creating autostart file directory:" << info.filePath();
+                qCWarning(KALARM_LOG) << "Preferences::setRunMode: Error creating autostart file directory:" << info.filePath();
                 return;
             }
         }
         QSaveFile file(autostartFileRW);
         if (!file.open(QIODevice::WriteOnly))
         {
-            qCWarning(KALARM_LOG) << "Preferences::setNoAutoStart: Error writing autostart file:" << autostartFileRW;
+            qCWarning(KALARM_LOG) << "Preferences::setRunMode: Error writing autostart file:" << autostartFileRW;
             return;
         }
         QTextStream stream(&file);
-        stream << lines.join(QLatin1Char('\n')) << "\n";
+        stream << lines.join('\n'_L1) << "\n";
         // QSaveFile doesn't report a write error when the device is full (see Qt
         // bug 75077), so check that the data can actually be written by flush().
         if (!file.flush()  ||  !file.commit())   // save the file
         {
-            qCWarning(KALARM_LOG) << "Preferences::setNoAutoStart: Error writing autostart file:" << autostartFileRW;
+            qCWarning(KALARM_LOG) << "Preferences::setRunMode: Error writing autostart file:" << autostartFileRW;
             return;
         }
-        qCDebug(KALARM_LOG) << "Preferences::setNoAutoStart: Written" << autostartFileRW;
+        qCDebug(KALARM_LOG) << "Preferences::setRunMode: Written" << autostartFileRW;
     }
 
-    self()->setBase_NoAutoStart(yes);
+    self()->setBase_RunMode(mode);
+    self()->setBase_AutoStart(mode == RunMode_Auto);
 }
 
 /******************************************************************************
@@ -355,7 +365,7 @@ QTimeZone Preferences::timeSpecAsZone()
 
 void Preferences::setTimeSpec(const KADateTime::Spec& spec)
 {
-    self()->setBase_TimeZone(spec.type() == KADateTime::TimeZone ? QString::fromLatin1(spec.timeZone().id()) : QString());
+    self()->setBase_TimeZone(spec.type() == KADateTime::TimeZone ? QString::fromLatin1(spec.namedTimeZone().id()) : QString());
 }
 
 void Preferences::timeZoneChange(const QString& zone)
