@@ -1,14 +1,14 @@
 /*
  *  resourcecreator.h  -  base class to interactively create a resource
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2020-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #pragma once
 
-#include <KAlarmCal/KACalendar>
+#include "kalarmcalendar/kacalendar.h"
 
 class QWidget;
 class Resource;
@@ -39,5 +39,4 @@ protected:
     KAlarmCal::CalEvent::Type mDefaultType;
 };
 
-
 // vim: et sw=4:
