@@ -1,13 +1,14 @@
 /*
  *  resourcescalendar.h  -  KAlarm calendar resources access
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2022 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2023 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #pragma once
 
+#include "kernelwakealarm.h"
 #include "resources/resource.h"
 #include "kalarmcalendar/kaevent.h"
 
@@ -32,25 +33,25 @@ class ResourcesCalendar : public QObject
     Q_OBJECT
 public:
     ~ResourcesCalendar() override;
-    static void             initialise(const QByteArray& appName, const QByteArray& appVersion);
-    static void             terminate();
+    static void           initialise(const QByteArray& appName, const QByteArray& appVersion);
+    static void           terminate();
 
     /** Return the active alarm with the earliest trigger time.
      *  @param nextTriggerTime       The next trigger time of the earliest alarm.
      *  @param excludeDisplayAlarms  Ignore display alarms.
      *  @return  The earliest alarm.
      */
-    static KAEvent          earliestAlarm(KADateTime& nextTriggerTime, bool excludeDisplayAlarms = false);
+    static KAEvent        earliestAlarm(KADateTime& nextTriggerTime, bool excludeDisplayAlarms = false);
 
-    static void             setAlarmPending(const KAEvent&, bool pending = true);
-    static bool             haveDisabledAlarms()       { return mHaveDisabledAlarms; }
-    static void             disabledChanged(const KAEvent&);
+    static void           setAlarmPending(const KAEvent&, bool pending = true);
+    static bool           haveDisabledAlarms()       { return mHaveDisabledAlarms; }
+    static void           disabledChanged(const KAEvent&);
     using QObject::event;
-    static KAEvent          event(const EventId& uniqueId, bool findUniqueId = false);
-    static KAEvent          templateEvent(const QString& templateName);
-    static QVector<KAEvent> events(const QString& uniqueId);
-    static QVector<KAEvent> events(const Resource&, CalEvent::Types = CalEvent::EMPTY);
-    static QVector<KAEvent> events(CalEvent::Types s = CalEvent::EMPTY);
+    static KAEvent        event(const EventId& uniqueId, bool findUniqueId = false);
+    static KAEvent        templateEvent(const QString& templateName);
+    static QList<KAEvent> events(const QString& uniqueId);
+    static QList<KAEvent> events(const Resource&, CalEvent::Types = CalEvent::EMPTY);
+    static QList<KAEvent> events(CalEvent::Types s = CalEvent::EMPTY);
 
     /** Options for addEvent(). May be OR'ed together. */
     enum AddEventOption
@@ -61,11 +62,11 @@ public:
     };
     Q_DECLARE_FLAGS(AddEventOptions, AddEventOption)
 
-    static bool             addEvent(KAEvent&, Resource&, QWidget* promptparent = nullptr, AddEventOptions options = NoOption, bool* cancelled = nullptr);
-    static bool             modifyEvent(const EventId& oldEventId, KAEvent& newEvent);
-    static KAEvent          updateEvent(const KAEvent&, bool saveIfReadOnly = true);
-    static bool             deleteEvent(const KAEvent&, Resource&, bool save = false);
-    static void             purgeEvents(const QVector<KAlarmCal::KAEvent>&);
+    static bool           addEvent(KAEvent&, Resource&, QWidget* promptparent = nullptr, AddEventOptions options = NoOption, bool* cancelled = nullptr);
+    static bool           modifyEvent(const EventId& oldEventId, KAEvent& newEvent);
+    static KAEvent        updateEvent(const KAEvent&, bool saveIfReadOnly = true);
+    static bool           deleteEvent(const KAEvent&, Resource&, bool save = false);
+    static void           purgeEvents(const QList<KAlarmCal::KAEvent>&);
     static ResourcesCalendar* instance()     { return mInstance; }
 
 Q_SIGNALS:
@@ -80,6 +81,8 @@ private Q_SLOTS:
     void                  slotEventsAdded(Resource&, const QList<KAlarmCal::KAEvent>&);
     void                  slotEventsToBeRemoved(Resource&, const QList<KAlarmCal::KAEvent>&);
     void                  slotEventUpdated(Resource&, const KAlarmCal::KAEvent&);
+    void                  slotAlarmsEnabledToggled(bool enabled);
+    void                  slotWakeFromSuspendAdvanceChanged(unsigned advance);
 private:
     ResourcesCalendar();
     static CalEvent::Type deleteEventInternal(const KAlarmCal::KAEvent&, Resource&, bool deleteFromResource = true);
@@ -87,11 +90,13 @@ private:
                                               bool deleteFromResource = true);
     void                  removeKAEvents(ResourceId, bool closing = false,
                                          CalEvent::Types = CalEvent::ACTIVE | CalEvent::ARCHIVED | CalEvent::TEMPLATE);
-    static QVector<KAEvent> events(CalEvent::Types, const Resource&);
+    static QList<KAEvent> events(CalEvent::Types, const Resource&);
     void                  findEarliestAlarm(const Resource&);
     void                  checkForDisabledAlarms();
     void                  checkForDisabledAlarms(bool oldEnabled, bool newEnabled);
-    static QVector<KAEvent> eventsForResource(const Resource&, const QSet<QString>& eventIds);
+    static QList<KAEvent> eventsForResource(const Resource&, const QSet<QString>& eventIds);
+    void                  setKernelWakeSuspend();
+    static void           checkKernelWakeSuspend(ResourceId, const KAlarmCal::KAEvent&);
 
     static ResourcesCalendar* mInstance;   // the unique instance
 
@@ -104,6 +109,10 @@ private:
     static QSet<QString>  mPendingAlarms;      // IDs of alarms which are currently being processed after triggering
     static bool           mIgnoreAtLogin;      // ignore new/updated repeat-at-login alarms
     static bool           mHaveDisabledAlarms; // there is at least one individually disabled alarm
+    // Wake from suspend kernel timers: indexed by resource and event ID.
+    // There is an entry for every enabled alarm with kernel wake from suspend specified.
+    // If alarms are disabled (for all alarms), the entries still exist with kernel timers disarmed.
+    static QHash<ResourceId, QHash<QString, KernelWakeAlarm>> mWakeSuspendTimers;
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(ResourcesCalendar::AddEventOptions)
