@@ -35,7 +35,7 @@ void TemplateMenuAction::slotInitMenu()
 
     // Compile a sorted list of template names
     QStringList sorted;
-    const QVector<KAEvent> templates = KAlarm::templateList();
+    const QList<KAEvent> templates = KAlarm::templateList();
     for (const KAEvent& templ : templates)
     {
         const QString name = templ.name();
@@ -67,4 +67,6 @@ void TemplateMenuAction::slotSelected(QAction* action)
     Q_EMIT selected(templ);
 }
 
+#include "moc_templatemenuaction.cpp"
+
 // vim: et sw=4:
